@@ -122,7 +122,7 @@ string url::encode(const string &data, const string &valid_reserved) {
 	return encoded.str();
 }
 
-url::url(const string url) throw(parse_error)
+url::url(const string &url) throw(parse_error)
 	: m_orig(url), m_port(0), m_ips(NULL) {
 	size_t idx = 0;
 	size_t hier_part_start, hier_part_end;
@@ -173,7 +173,7 @@ url::url(const string url) throw(parse_error)
 	 *		      / path-empty
 	 */
 
-	if (hier_part[0] == '/' && hier_part[1] == '/') {
+	if (hier_part.size() >= 2 && hier_part[0] == '/' && hier_part[1] == '/') {
 		size_t authority_start, authority_end;
 		size_t userinfo_start, userinfo_end;
 		size_t host_start, host_end;
@@ -181,6 +181,8 @@ url::url(const string url) throw(parse_error)
 		authority_start = 2;
 		/* authority is always followed by / or nothing */
 		authority_end = hier_part.find('/', authority_start);
+                if (authority_end == string::npos)
+                  authority_end = hier_part.size();
 		path_start = authority_end;
 
 		/* 3.2:
@@ -230,12 +232,13 @@ url::url(const string url) throw(parse_error)
 		/* Get port */
 		m_port = get_default_port(m_scheme);
 
-		if (hier_part[host_end] == ':') {
+		if (host_end != hier_part.size()
+			&& hier_part[host_end] == ':') {
 			size_t port_start = host_end + 1;
 			m_port = atoi(hier_part.c_str() + port_start);
 		}
 	} else {
-		path_start = hier_part_start;
+		path_start = 0;
 	}
 
 	/* Get path */
